import getUrlContents from '../getUrlContents';
import { Product } from '../interfaces/ISettings';
import verifyProductName from '../verifyProductName';

export default function getSolidpkg(product: Product, from: number, to: number): Promise<Buffer> {
  //Verify function arguments
  if (!verifyProductName(product)) {
    throw new Error(`"${product}" is not a valid product.`);
  }

  if (typeof from !== 'number' || (from | 0) !== from || from < -1) {
    throw new Error(`from must be an integer greater than or equal to -1 but it is "${from}"`);
  }
  if (typeof to !== 'number' || (to | 0) !== to || to < 0) {
    throw new Error(`to must be an integer greater than or equal to 0 but it is "${to}"`);
  }
  if (from >= to) {
    throw new Error(`from must be less than to but "${from}" is not less than "${to}".`);
  }

  return getUrlContents({ host: 'cdn-patch.swtor.com', path: `/patch/${product}/${product}_${from}to${to}.solidpkg` });
}
